# ONEcityAPI Usage Guide

ONEcityAPI is a Python wrapper for the ONEcity API. It provides a simple way to interact with the API and retrieve water consumption and customer information.


## Usage

To use the ONEcityAPI, you need to create a `User` object and a `ONEcityAPI` object. The `User` object requires four parameters: `userName`, `password`, `customerID`, and `customerSite`.

`customerID` and `customerSite` are equal and can be found in the [Customer ID Table](#customer-id-table).

Here is an example of how to create a `User` object and a `ONEcityAPI` object:

```python
from ONEcityAPI.user import User
from ONEcityAPI import ONEcityAPI

user = User('123456789', 'password', 'customerID', 'customerSite')
api = ONEcityAPI(user)
```

After creating the `ONEcityAPI` object, you can call the `get_water_consumption` method to retrieve the water consumption data and the `get_customer_info` method to retrieve the customer information.

Here is an example of how to call these methods:

```python
print(api.get_water_consumption())
print(api.get_customer_info())
```

The `get_water_consumption` method returns a `Consumptions` object that contains a list of `Consumption` objects. Each `Consumption` object represents a water consumption entry.

The `get_customer_info` method returns a `Customer` object that contains the number of persons and the rates.

Please note that you need to replace the `userName`, `password`, `customerID`, and `customerSite` with your actual details.


## Customer ID Table

Locate your Customer ID based on the city name

| CUSTOMER_ID | CUSTOMER_NAME         |
|------------|--------------------------|
| 526600     | יבנה                     |
| 835600     | אלקנה                   |
| 2002       | אתר קניון חיפה         |
| 909980     | ביר אל מכסור           |
| 504660     | בית דגן                |
| 62410      | בני שמעון               |
| 44280      | ברנר                   |
| 262000     | בת ים                   |
| 905100     | כפר מנדא                |
| 29710      | גולן                   |
| 43300      | גזר                     |
| 502200     | גני תקווה               |
| 42200      | דרום השרון              |
| 23080      | הגלבוע                 |
| 77780      | הר חברון                |
| 42250      | חבל מודיעין             |
| 927200     | טירה                   |
| 594000     | יהוד - מונוסון          |
| 602400     | יקנעם עילית            |
| 712710     | להבים                  |
| 371100     | מי אשקלון              |
| 472050     | מי ציונה- נס ציונה     |
| 367100     | מי רקת                 |
| 266500     | מי שיקמה אור יהודה    |
| 266600     | מי שקמה בית דגן      |
| 266400     | מי שקמה חולון          |
| 326500     | מים אילת               |
| 836080     | מעלה אפרים             |
| 2000       | מרכז מסחרי שהם        |
| 472000     | נס ציונה               |
| 502460     | נתיבות                |
| 705870     | סביון                 |
| 706660     | עומר                  |
| 62390      | שדות נגב              |
| 905300     | עילבון                |
| 22060      | עמק הירדן             |
| 41160      | עמק חפר               |
| 600530     | עתלית                |
| 2001       | פלג הגליל             |
| 905360     | פקיעין                |
| 801710     | פרדסיה                |
| 279500     | פתח תקווה - מיטב ( מים ) |
| 813080     | צורן                 |
| 835570     | קדומים                |
| 601950     | קדימה - צורן           |
| 426200     | קרית אונו             |
| 395000     | קרית ביאליק           |
| 468000     | קרית אתא             |
| 326310     | קרית גת ? מרכז מריאן |
| 423000     | קרית טבעון           |
| 396000     | קרית ים              |
| 382000     | קרית מוצקין          |
| 504690     | קרית עקרון           |
| 328000     | קרית שמונה           |
| 61340      | שפיר                 |
| 510150     | מבשרת ציון            |
| 300770     | אשדוד - יובלים       |
| 500310     | אופקים               |
| 835700     | אריאל                |
| 960000     | באקה- אל גרביה       |
| 601660     | גן יבנה              |
| 0.8232972  | גן רוה               |
| 693000     | זכרון יעקב           |
| 906470     | זמר                  |
| 32150      | חוף הכרמל           |
| 594100     | יהוד אגח            |
| 61350      | יואב                 |
| 905040     | כאבול                |
| 812630     | כפר ורדים           |
| 41180      | לב השרון            |
| 23130      | מגידו                |
| 0.4765515  | מודיעין עילית        |
| 836160     | מעלה אדומים          |
| 21020      | מרום הגליל           |
| 373000     | נצרת                |
| 975000     | סח'נין               |
| 0.6891137  | עספיא               |
| 800260     | ראש פינה            |
| 508120     | שלומי               |
| 601540     | תל מונד             |
| 140000     | חיפה                |
| 274000     | נתניה               |
| 904780     | אכסאל               |
| 927100     | אום אל פאחם         |
| 880100     | אלעין               |
| 263000     | גבעתיים             |
| 904940     | דלית אל כרמל       |
| 22030      | הגליל התחתון        |
| 62540      | הערבה התיכונה       |
| 264000     | הרצליה              |
| 520340     | חצור הגלילית        |
| 521000     | טירת כרמל           |
| 904990     | יפיע                |
| 906540     | כפר קרע             |
| 800470     | כפר תבור            |
| 880850     | כרמיאל-עין כרמים  |
| 800650     | מגדל                |
| 24040      | מטה אשר             |
| 700430     | מטולה               |
| 502400     | מי אשקלון-נתיבות   |
| 812100     | מי מודיעין          |
| 473050     | מי ציונה- קריית עקרון |
| 367700     | מי רקת             |
| 880090     | מעיינות השרון       |
| 526400     | ראש העין           |
| 186100     | תאגיד מי רמת גן   |
| 989000     | תמרה               |
| 279000     | פתח תקווה           |
| 261000     | בני ברק            |
| 524000     | אור יהודה           |
| 600410     | אליכין              |
| 925660     | בוסתן אל מרג      |
| 537800     | ביתר עילית         |
| 698000     | בנימינה-גבעת עדה  |
| 265000     | חדרה               |
| 800460     | יבנאל              |
| 269000     | כפר סבא           |
| 812000     | מודיעין           |
| 140100     | מי כרמל           |
| 487100     | מי רעננה          |
| 712680     | מיתר              |
| 880300     | מעיינות העמקים  |
| 62520      | מעלה יוסף          |
| 24560      | משגב              |
| 310610     | נצרת עילית         |
| 23090      | עמק יזרעאל         |
| 841000     | קצרין              |
| 382100     | קרית מוצקין-פלגי מוצקין |
| 186000     | רמת גן           |
| 426500     | רמת השרון         |
| 801220     | רמת ישי          |
| 487000     | רעננה             |
| 566100     | תאגיד מים מי שמש |
| 150000     | תל אביב            |
| 326000     | אילת               |
| 601820     | אבן יהודה         |
| 510200     | אור עקיבא        |
| 32450      | אלונה             |
| 813090     | אלעד              |
| 51240      | אפעל              |
| 836500     | אפרת             |
| 300700     | אשדוד            |
| 592000     | בית שאן          |
| 697000     | הוד השרון        |
| 913030     | חורה             |
| 904960     | חורפיש           |
| 61500      | לכיש             |
| 905170     | מזרעה            |
| 697100     | מי הוד השרון     |
| 927150     | מי עירון         |
| 880200     | מעיינות הדרום   |
| 500990     | מצפה רמון       |
| 376000     | עכו               |
| 377000     | עפולה            |
| 906370     | ערערה            |
| 807300     | גבעת זאב         |
| 44290      | חבל יבנה         |
| 61330      | באר טוביה        |
| 61370      | שער הנגב         |
| 62380      | אשכול            |
| 371001     | אשקלון-קייטנות  |
| 625500     | גדרה              |
| 702670     | כפר שמריהו       |
| 837600     | אורנית           |
| 837690     | הר אדר           |
| 380000     | צפת              |
| 390000     | באר שבע          |
| 904730     | אבו סנאן         |
| 511390     | כרבייאל          |
| 367000     | טבריה            |
| 880500     | קרית ים מים-ימים |
| 905320     | עין מאהל        |
| 283000     | ראשון לציון     |
| 625300     | באר יעקב         |
| 906270 | ג'לג'וליה          |
| 904830 | בענה                 |
| 909440 | בסמת טבעון         |
| 905070 | כפר יאסיף           |
| 905000 | יאנוח ג'ת           |
| 905200 | משהד                 |
| 905250 | סאגור                |
| 992640 | הרצליה - תשלומים   |
| 23070  | מעיינות             |
| 283200 | ראשון לציון חניונים |
| 266000 | חולון                |
| 905060 | כסרא סמיע           |
| 186330 | עמותת על"ה רמת גן  |
| 905050 | כאוכב                |
| 905380 | שעב                  |
| 434002 | ועדת יזרעאלים       |
| 44270  | גן רווה              |
| 61360  | חוף אשקלון          |
| 62480  | רמת הנגב            |
| 405650 | אזור                 |
| 234000 | שמים כחולים         |
| 468100 | מעיינות אתא         |
| 380100 | פלג הגליל           |
| 385000 | אותו                 |
| 264100 | מי הרצליה           |
| 880020 | תפן                  |
| 710620 | אותו                 |
| 800290 | יסוד המעלה          |
| 813510 | מודיעין מכבים רעות |
| 508740 | מגדל העמק          |
| 62680  | נווה מדבר           |
| 904810 | מגאר                |
| 904820 | בועיינה נוגידאת   |
| 904980 | טורעאן              |
| 905370 | פרדיס               |
| 906380 | קלנסואה            |
| 909620 | טובה זנגריה        |
| 913260 | בסמה                |
| 927300 | טייבה               |
| 942010 | מגדל שמס           |
| 992610 | בני ברק - תשלומים |
| 993260 | אילת (תשלומים)     |
| 993850 | רמלה                |
| 996600 | חולון - תשלומים    |
| 992740 | נתניה-תשלומים       |
| 927160 | מי עירון-באקה      |
| 927170 | מי עירון-ערערה     |
| 927180 | מי עירון-זמר       |
| 927190 | מי עירון-טייבה     |
| 910590 | כסייפה             |
| 836520 | בית אריה            |
| 904870 | גוש חלב            |
| 43400  | שדות דן            |
| 22050  | קדמת גליל          |
| 712240 | כוכב יאיר - צור יגאל |
| 391000 | באר שבע-כיוונים |
| 925650 | אל בטוף            |
| 912860 | שגב שלום          |
| 905410 | גסר אל זרקא      |
| 284000 | רחובות             |
| 44310  | נחל שורק          |
| 909750 | זרזיר              |
| 526100 | בית שמש           |
| 904840 | ג'דידה מכר        |
| 906280 | גת                |
| 21010  | הגליל העליון     |
| 880060 | כפרי גליל תחתון |
| 32140  | מנשה              |
| 905340 | עספיא             |
| 525600 | ערד               |
| 678000 | פרדס חנה - כרכור |
| 812470 | חריש              |
| 326300 | קרית גת          |
| 73720  | שומרון           |
| 837300 | גבעת זאב - חינוך |
| 904890 | דבוריה            |
| 508310 | ירוחם            |
| 905080 | כפר קמא          |
| 712730 | מכבים רעות       |
| 510340 | קרית מלאכי      |
| 269100 | מפעל המים כפר סבא |
| 322000 | דימונה           |
| 31120  | זבולון           |
| 905090 | כפר כנא          |
| 370000 | לוד               |
| 11260  | מטה יהודה        |
| 474050 | מי ציונה- מזכרת בתיה |
| 371000 | אשקלון          |
| 904850 | ג'וליס           |
| 911920 | ערערה בנגב      |
| 905220 | נחף              |
| 940010 | בוקעתא          |
| 905420 | ריינה            |
| 905290 | אעבלין           |
